@@ -2,8 +2,12 @@
 # bibmanager is open-source software under the MIT license (see LICENSE).
 
 from .bib_manager import *
-from .bib_manager import __all__
+from .browser import *
 
+__all__ = (
+      bib_manager.__all__
+    + browser.__all__
+)
 
 # Clean up top-level namespace--delete everything that isn't in __all__
 # or is a magic attribute, and that isn't a submodule of this package
